@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

.sc_events {
	position: relative;	
}

.sc_events_button {
	text-align:center;
}


/* Style 'Default'
--------------------------------------- */
.sc_events_default .sc_events_item {
	@include flex;
	@include flex-direction(row);
	@include flex-wrap(nowrap);
	@include flex-align-items(center);
	@include flex-justify-content(space-between);
	margin-bottom: 2em;
}
.sc_events_default .sc_events_item:last-child {
	margin-bottom: 0;
}
.sc_events_default .sc_events_item_thumb {
	position: relative;
	margin-bottom: 0;
	overflow: visible !important;
	width: 30%;
}
.sc_events_default .sc_events_item_info {
	padding: 0 2em;
	width: 60%;
	position: relative;
}
// .sc_events_default.without_button .sc_events_item_info {
// 	width: 70%;
// }
.sc_events_default .sc_events_item_thumb .sc_events_item_date {
	@include abs-lc;
	z-index: 10;
	@include translate(-50%, -50%);
	padding: 1em;
	background-color: #f0f0f0;
	@include transition-properties(color, background-color);
}
.sc_events_default .sc_events_item_thumb .sc_events_item_date_day,
.sc_events_default .sc_events_item_thumb .sc_events_item_date_month {
	display: block;
	text-align: center;
}
.sc_events_default .sc_events_item_thumb .sc_events_item_date_day {
	@include font(1.75em, 1.4em);
	color: #efa758;
	@include transition-property(color);
}
.sc_events_default .sc_events_item_title {
	margin: 0.2em 0 0.4em;
}
.sc_events_default .sc_events_item_meta {
	color: #888;
	font-size: 12px;
}
// .sc_events_default .sc_events_item.with_price .sc_events_item_meta {
// 	padding-right: 25%;
// }
.sc_events_default .sc_events_item_meta .sc_events_item_meta_date_separator {
	margin: 0 0.5em;
}
.sc_events_default .sc_events_item_price {
	color: #efa758;
	@include abs-rt(1.4em);
	@include font(1.5em, 1.4em);
}
.sc_events_default .sc_events_item_button {
	text-align: right;
}


/* Style 'Classic'
--------------------------------------- */
.sc_events_classic .sc_events_item {
	background-color:#fafafa;
}
.sc_events_classic .sc_events_item_thumb {
	position: relative;
	margin-bottom: 0;
}
.sc_events_classic .sc_events_item_thumb[class*="hover_"] {
	display: block;
}
.sc_events_classic .sc_events_item_thumb img {
	width: 100%;
}
.sc_events_classic .sc_events_item_categories {
	@include abs-lt(2em, 2em);
	display:inline-block;
	background-color: #292929;
	@include font(0.9286em, 2em);
	padding: 0 0.7em;
	text-transform:uppercase;
}
.sc_events_classic .sc_events_item_categories a {
	color: #fff;
}
.sc_events_classic .sc_events_item_categories a:hover {
	color: #efa758;
}
.sc_events_classic .sc_events_item_info {
	padding: 2em;
}
.sc_events_classic .sc_events_item_title {
	margin: 0;
}
.sc_events_classic .sc_events_item_title {
	margin: 0;
}
.sc_events_classic .sc_events_item_meta {
	@include font(0.9286em, 1.5em);
	margin-top: 0.5em;
}
.sc_events_classic .sc_events_item_meta_item + .sc_events_item_meta_item:before {
	content: '*';
	margin:0 0.3em;
}
.sc_events_classic .sc_events_item_date {
	letter-spacing: 0;
	font-style: italic;
}
.sc_events_classic .sc_events_item_price {
	@include font(2em, 1em);
	margin-top: 0.5em;
	color: #efa758;
	min-height:1.2em;
}
.sc_events_classic .sc_events_item_period {
	font-size:0.4em;
	color: #888;
	text-transform:uppercase;
}
.sc_events_classic .sc_events_item_period:before {
	content: '/';
	margin: 0 0.5em;
}

/* Hover */
.sc_events_classic .sc_events_item .trx_addons_hover_mask {
	background-color: #000;
}
.sc_events_classic .trx_addons_hover_content .trx_addons_hover_title {
	background-color: transparent;
	padding: 0;
	margin:0;
	text-transform:none;
	font-size: 1.6667em;
}
.sc_events_classic .trx_addons_hover_content .trx_addons_hover_text {
	padding:0;
	margin-top:2em;
	font-style:normal;
}
.sc_events_classic .trx_addons_hover_content .trx_addons_hover_links a {
	margin-top: 3em;
	@include font(12px, '', bold);
	text-transform:uppercase;
	letter-spacing:1px;
	padding:1.3em 1.9em;
}
